aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorBrian Dolbec <dolsen@gentoo.org>2013-02-10 12:06:15 -0800
committerBrian Dolbec <dolsen@gentoo.org>2013-11-21 21:44:40 -0800
commit19d2fadbf4f1565f54b6deac443344a50cb7e81c (patch)
tree88560d33365ac02afa285d8be71b18dec3f3b8f5
parentAdd archdir to settings (diff)
downloadcatalyst-19d2fadbf4f1565f54b6deac443344a50cb7e81c.tar.gz
catalyst-19d2fadbf4f1565f54b6deac443344a50cb7e81c.tar.bz2
catalyst-19d2fadbf4f1565f54b6deac443344a50cb7e81c.zip
Fix a bug that portage didn't get rebuilt with the build use flag
If clst_PGKCACHE is defined, --newuse was not being added to clst_myemergeopts, so then portage was not being rebuilt if portage was already up to date.
-rwxr-xr-xtargets/support/chroot-functions.sh7
1 files changed, 4 insertions, 3 deletions
diff --git a/targets/support/chroot-functions.sh b/targets/support/chroot-functions.sh
index 5c30537b..010f5278 100755
--- a/targets/support/chroot-functions.sh
+++ b/targets/support/chroot-functions.sh
@@ -168,10 +168,11 @@ setup_gcc(){
setup_pkgmgr(){
# We need to merge our package manager with USE="build" set in case it is
# portage to avoid frying our /etc/portage/make.conf file. Otherwise, we could
# just let emerge @system could merge it.
# Use --update or portage won't reinstall the same version.
[ -e /etc/portage/make.conf ] && echo 'USE="${USE} build"' >> /etc/portage/make.conf
- run_merge --oneshot --nodeps --update sys-apps/portage
+ run_merge --oneshot --nodeps --update --newuse sys-apps/portage
sed -i '/USE="${USE} build"/d' /etc/portage/make.conf
}
@@ -168,10 +168,11 @@ setup_gcc(){
# We need to merge our package manager with USE="build" set in case it is
# portage to avoid frying our /etc/portage/make.conf file. Otherwise, we could
- # just let emerge @system could merge it.
- # Use --update or portage won't reinstall the same version.
+ # just let emerge system could merge it.
+ # Use --update or portage won't reinstall the same version later.
+ # Use --newuse to make sure it rebuilds with the "build" use flag.
[ -e /etc/portage/make.conf ] && echo 'USE="${USE} build"' >> /etc/portage/make.conf